@@ -15,7 +15,7 @@ The Consumer and BufferedConsumer classes allow callers to
 customize the IO characteristics of their tracking.
 '''
 
-VERSION = '2.0.0'
+VERSION = '2.0.1'
 
 class Mixpanel(object):
     '''
@@ -208,18 +208,17 @@ class Mixpanel(object):
         properties.update({'$amount': amount})
         return self.people_append(distinct_id, {'$transactions': properties})
 
-
-    """
-    Send a generic update to \Mixpanel people analytics.
-    Caller is responsible for formatting the update message, as
-    documented in the \Mixpanel HTTP specification, and passing
-    the message as a dict to update. This
-    method might be useful if you want to use very new
-    or experimental features of people analytics from Ruby
-    The \Mixpanel HTTP tracking API is documented at
-    https://mixpanel.com/help/reference/http
-    """
     def people_update(self, message):
+        """
+        Send a generic update to Mixpanel people analytics.
+        Caller is responsible for formatting the update message, as
+        documented in the Mixpanel HTTP specification, and passing
+        the message as a dict to update. This
+        method might be useful if you want to use very new
+        or experimental features of people analytics from python
+        The Mixpanel HTTP tracking API is documented at
+        https://mixpanel.com/help/reference/http
+        """
         record = {
             '$token': self._token,
             '$time': int(self._now() * 1000),
@@ -227,8 +226,6 @@ class Mixpanel(object):
         record.update(message)
         self._consumer.send('people', json.dumps(record))
 
-
-
 class MixpanelException(Exception):
     '''
     MixpanelExceptions will be thrown if the server can't recieve
@@ -246,7 +243,7 @@ class Consumer(object):
     def __init__(self, events_url=None, people_url=None):
         self._endpoints = {
             'events': events_url or 'https://api.mixpanel.com/track',
-            'people': people_url or 'https://api.mixpanel.com/people',
+            'people': people_url or 'https://api.mixpanel.com/engage',
         }
 
     def send(self, endpoint, json_message):
